% start with bicycle model%
function yprime=bicycle(t,y);

%--------------------------------------
% Constants
%--------------------------------------

kp = 1;    % proportional gain
kd = .0;     % derivative gain
tau = 0.05;   % steering servo time constant
slew_rate = 1.0/tau; % slew rate, radians per second
V = 3.0;     % car speed m/s
L = 0.3;     % car length m


%--------------------------------------
% Differential Equations
%--------------------------------------

% thetadot: y(1) = car orientation angle theta
% yadot: y(2) = y position of front of car (ya)
% xbdot: y(3) = x position of back of car (xb)
% ybdot: y(4) = y position of back of car (yb)
% delta_dot: y(5) = steering angle delta

xbdot = V*cos(y(1));
ybdot =	-V*sin(y(1));
thetadot = (V/L)*tan(y(5));
yadot = -V*(sin(y(1)) + tan(y(5))*cos(y(1)));
xadot = V*(cos(y(1)) - tan(y(5))*sin(y(1)));

xa = y(3) + L * cos(y(1));
ya = y(2);
%r1 = sqrt(xa*xa + y(2)*y(2));

errout = track_2011(xa,ya,xadot,yadot);
e = errout(1);
edot = errout(2);


delta_dot = (1/tau) * (- y(5) + kp * e + kd * edot); %PD controller
delta_dot = min(delta_dot, slew_rate); %limits of servo
delta_dot = max(delta_dot, -slew_rate); %limits of servo

yprime=[ thetadot
	 yadot
	xbdot
	ybdot
	delta_dot];


